@@ -39,7 +39,7 @@
 
 struct _ExmDetailView
 {
-    GtkBox parent_instance;
+    AdwNavigationPage parent_instance;
 
     ExmManager *manager;
     ExmDataProvider *provider;
@@ -71,13 +71,15 @@ struct _ExmDetailView
 	AdwBin *image_overlay;
 	ExmZoomPicture *overlay_screenshot;
 
+    AdwActionRow *link_homepage;
+    gchar *uri_homepage;
     AdwActionRow *link_extensions;
     gchar *uri_extensions;
     int pk;
     guint signal_id;
 };
 
-G_DEFINE_FINAL_TYPE (ExmDetailView, exm_detail_view, GTK_TYPE_BOX)
+G_DEFINE_FINAL_TYPE (ExmDetailView, exm_detail_view, ADW_TYPE_NAVIGATION_PAGE)
 
 enum {
     PROP_0,
@@ -210,7 +212,14 @@ on_get_comments (GObject       *source,
         return;
     }
 
-    gtk_stack_set_visible_child_name (self->comment_stack, "page_comments");
+    if (g_list_model_get_n_items (model) == 0)
+    {
+        gtk_stack_set_visible_child_name (self->comment_stack, "page_empty");
+    }
+    else
+    {
+        gtk_stack_set_visible_child_name (self->comment_stack, "page_comments");
+    }
 
     gtk_flow_box_bind_model (self->comment_box, model,
                              (GtkListBoxCreateWidgetFunc) comment_factory,
@@ -279,7 +288,7 @@ on_data_loaded (GObject      *source,
     {
         gint pk;
         gboolean is_installed, is_supported;
-        gchar *uuid, *name, *creator, *icon_uri, *screenshot_uri, *link, *description;
+        gchar *uuid, *name, *creator, *icon_uri, *screenshot_uri, *link, *description, *url;
         g_object_get (data,
                       "uuid", &uuid,
                       "name", &name,
@@ -290,6 +299,7 @@ on_data_loaded (GObject      *source,
                       "description", &description,
                       "shell_version_map", &version_map,
                       "pk", &pk,
+                      "url", &url,
                       NULL);
 
         adw_window_title_set_title (self->title, name);
@@ -334,11 +344,17 @@ on_data_loaded (GObject      *source,
 
         g_object_set (self->ext_install, "state", install_state, NULL);
 
+        self->uri_homepage = g_uri_resolve_relative (url,
+                                                     "",
+                                                     G_URI_FLAGS_NONE,
+                                                     NULL);
+
         self->uri_extensions = g_uri_resolve_relative ("https://extensions.gnome.org/",
                                                        link,
                                                        G_URI_FLAGS_NONE,
                                                        NULL);
 
+        adw_action_row_set_subtitle (self->link_homepage, self->uri_homepage);
         adw_action_row_set_subtitle (self->link_extensions, self->uri_extensions);
 
         // Clear Flowbox
@@ -405,7 +421,7 @@ exm_detail_view_load_for_uuid (ExmDetailView *self,
     adw_window_title_set_subtitle (self->title, NULL);
 
     gtk_stack_set_visible_child_name (self->stack, "page_spinner");
-	gtk_widget_hide (GTK_WIDGET (self->image_overlay));
+    gtk_widget_set_visible (GTK_WIDGET (self->image_overlay), FALSE);
 
     exm_data_provider_get_async (self->provider, uuid, NULL, on_data_loaded, self);
 }
@@ -430,18 +446,18 @@ open_link (ExmDetailView *self,
            GVariant      *param)
 {
     GtkWidget *toplevel;
-    gchar *uri = NULL;
+    GtkUriLauncher *uri = NULL;
 
     toplevel = GTK_WIDGET (gtk_widget_get_root (GTK_WIDGET (self)));
 
     if (strcmp (action_name, "detail.open-extensions") == 0)
-        uri = self->uri_extensions;
+        uri = gtk_uri_launcher_new (self->uri_extensions);
     else if (strcmp (action_name, "detail.open-homepage") == 0)
-        g_warning ("open_link(): cannot open homepage as not yet implemented.");
+        uri = gtk_uri_launcher_new (self->uri_homepage);
     else
         g_critical ("open_link() invalid action: %s", action_name);
 
-    gtk_show_uri (GTK_WINDOW (toplevel), uri, GDK_CURRENT_TIME);
+    gtk_uri_launcher_launch (uri, GTK_WINDOW (toplevel), NULL, NULL, NULL);
 }
 
 static void
@@ -530,6 +546,7 @@ exm_detail_view_class_init (ExmDetailViewClass *klass)
 	gtk_widget_class_bind_template_child (widget_class, ExmDetailView, ext_screenshot_popout_button);
 	gtk_widget_class_bind_template_child (widget_class, ExmDetailView, ext_screenshot_popin_button);
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, supported_versions);
+    gtk_widget_class_bind_template_child (widget_class, ExmDetailView, link_homepage);
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, link_extensions);
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, scroll_area);
     gtk_widget_class_bind_template_child (widget_class, ExmDetailView, comment_box);
@@ -542,6 +559,16 @@ exm_detail_view_class_init (ExmDetailViewClass *klass)
     gtk_widget_class_install_action (widget_class, "detail.open-homepage", NULL, open_link);
 }
 
+static void
+widget_show(GtkWidget *widget) {
+    gtk_widget_set_visible(widget, TRUE);
+}
+
+static void
+widget_hide(GtkWidget *widget) {
+    gtk_widget_set_visible(widget, FALSE);
+}
+
 static void
 exm_detail_view_init (ExmDetailView *self)
 {
@@ -577,11 +604,11 @@ exm_detail_view_init (ExmDetailView *self)
 
 	g_signal_connect_swapped (self->ext_screenshot_popout_button,
 							  "clicked",
-							  G_CALLBACK (gtk_widget_show),
+							  G_CALLBACK (widget_show),
 							  self->image_overlay);
 
 	g_signal_connect_swapped (self->ext_screenshot_popin_button,
 							  "clicked",
-							  G_CALLBACK (gtk_widget_hide),
+							  G_CALLBACK (widget_hide),
 							  self->image_overlay);
 }
