@@ -173,7 +173,7 @@ update_checked_count (ExmUpgradeAssistant *self)
 {
     char *text;
 
-    text = g_strdup_printf ("Checked %d/%d extensions",
+    text = g_strdup_printf (_("Checked %d/%d extensions"),
                             self->number_checked,
                             self->total_extensions);
 
@@ -192,7 +192,7 @@ display_results (ExmUpgradeAssistant *self)
     gtk_progress_bar_set_fraction (self->progress_bar, fraction);
 
     // Set percentage text
-    text = g_strdup_printf ("%d%% Compatible", (int)(fraction * 100));
+    text = g_strdup_printf (_("%d%% Compatible"), (int)(fraction * 100));
     gtk_progress_bar_set_text (self->progress_bar, text);
     free (text);
 
@@ -498,6 +498,7 @@ widget_factory (ExmUpgradeResult    *result,
     gtk_box_append (GTK_BOX (hbox), vbox);
 
     label = gtk_label_new (name);
+    gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
     gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
     gtk_widget_add_css_class (label, "heading");
     gtk_box_append (GTK_BOX (vbox), label);
@@ -650,12 +651,14 @@ exm_upgrade_assistant_class_init (ExmUpgradeAssistantClass *klass)
     gtk_widget_class_bind_template_child (widget_class, ExmUpgradeAssistant, progress_bar);
     gtk_widget_class_bind_template_child (widget_class, ExmUpgradeAssistant, summary);
     gtk_widget_class_bind_template_child (widget_class, ExmUpgradeAssistant, copy_details);
+
+    gtk_widget_class_add_binding_action (widget_class, GDK_KEY_Escape, 0, "window.close", NULL);
 }
 
 static void
 exm_upgrade_assistant_init (ExmUpgradeAssistant *self)
 {
-    GtkWidget *placeholder;
+    GtkWidget *placeholder, *icon;
 
     gtk_widget_init_template (GTK_WIDGET (self));
 
@@ -683,12 +686,14 @@ exm_upgrade_assistant_init (ExmUpgradeAssistant *self)
     bind_list_box (self, self->system_list_box, G_LIST_MODEL (self->system_results_store));
 
     placeholder = adw_action_row_new ();
-    adw_action_row_set_icon_name (ADW_ACTION_ROW (placeholder), "puzzle-piece-symbolic");
+    icon = gtk_image_new_from_icon_name ("puzzle-piece-symbolic");
+    adw_action_row_add_prefix (ADW_ACTION_ROW (placeholder), icon);
     adw_preferences_row_set_title (ADW_PREFERENCES_ROW (placeholder), _("There are no user extensions installed."));
     gtk_list_box_set_placeholder (self->user_list_box, placeholder);
 
     placeholder = adw_action_row_new ();
-    adw_action_row_set_icon_name (ADW_ACTION_ROW (placeholder), "settings-symbolic");
+    icon = gtk_image_new_from_icon_name ("settings-symbolic");
+    adw_action_row_add_prefix (ADW_ACTION_ROW (placeholder), icon);
     adw_preferences_row_set_title (ADW_PREFERENCES_ROW (placeholder), _("There are no system extensions installed."));
     gtk_list_box_set_placeholder (self->system_list_box, placeholder);
 
