@@ -40,10 +40,10 @@ struct _ExmWindow
     AdwHeaderBar         *header_bar;
     ExmBrowsePage        *browse_page;
     ExmInstalledPage     *installed_page;
-    AdwLeaflet           *leaflet;
-    GtkWidget            *main_view;
+    AdwNavigationView    *navigation_view;
+    AdwNavigationPage    *main_view;
     ExmDetailView        *detail_view;
-    AdwViewSwitcherTitle *title;
+    AdwViewSwitcher      *title;
     AdwViewStack         *view_stack;
     AdwToastOverlay      *toast_overlay;
 };
@@ -145,12 +145,12 @@ typedef struct
 
 static void
 extension_remove_dialog_response (GtkDialog        *dialog,
-                                  int               response_id,
+                                  const char       *response,
                                   RemoveDialogData *data)
 {
     gtk_window_destroy (GTK_WINDOW (dialog));
 
-    if (response_id == GTK_RESPONSE_YES)
+    if (strcmp(response, "yes") == 0)
     {
         exm_manager_remove_extension (data->manager, data->extension);
     }
@@ -176,18 +176,26 @@ extension_remove (GtkWidget  *widget,
 
     GtkWidget *dlg;
 
-    dlg = gtk_message_dialog_new (GTK_WINDOW (self),
-                                  GTK_DIALOG_MODAL,
-                                  GTK_MESSAGE_QUESTION,
-                                  GTK_BUTTONS_YES_NO,
-                                  _("Are you sure you want to uninstall?"));
+    dlg = adw_message_dialog_new (GTK_WINDOW (self),
+                                  _("Uninstall Extension?"),
+                                  _("The extension's features and functionality will no longer be accessible. Are you sure you want to uninstall?"));
+
+    adw_message_dialog_add_responses (ADW_MESSAGE_DIALOG (dlg),
+                                      "no", _("_No"),
+                                      "yes", _("_Yes"),
+                                      NULL);
+
+    adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (dlg), "yes", ADW_RESPONSE_DESTRUCTIVE);
+
+    adw_message_dialog_set_default_response (ADW_MESSAGE_DIALOG (dlg), "no");
+    adw_message_dialog_set_close_response (ADW_MESSAGE_DIALOG (dlg), "no");
 
     RemoveDialogData *data = g_new0 (RemoveDialogData, 1);
     data->manager = g_object_ref (self->manager);
     data->extension = g_object_ref (extension);
 
     g_signal_connect (dlg, "response", G_CALLBACK (extension_remove_dialog_response), data);
-    gtk_widget_show (dlg);
+    gtk_window_present (GTK_WINDOW (dlg));
 }
 
 static void
@@ -210,12 +218,12 @@ typedef struct
 
 static void
 extension_unsupported_dialog_response (GtkDialog             *dialog,
-                                       int                    response_id,
+                                       const char            *response,
                                        UnsupportedDialogData *data)
 {
     gtk_window_destroy (GTK_WINDOW (dialog));
 
-    if (response_id == GTK_RESPONSE_YES)
+    if (strcmp(response, "yes") == 0)
     {
         exm_manager_install_async (data->manager, data->uuid, NULL,
                                    (GAsyncReadyCallback) on_install_done,
@@ -243,18 +251,27 @@ extension_install (GtkWidget  *widget,
     {
         GtkWidget *dlg;
 
-        dlg = gtk_message_dialog_new (GTK_WINDOW (self),
-                                      GTK_DIALOG_MODAL,
-                                      GTK_MESSAGE_QUESTION,
-                                      GTK_BUTTONS_YES_NO,
-                                      _("This extension does not support your GNOME Shell version.\nWould you like to install anyway?"));
+        dlg = adw_message_dialog_new (GTK_WINDOW (self),
+                                      _("Unsupported Extension"),
+                                      _("This extension does not support your GNOME Shell version. It may cause errors if installed."));
+
+        adw_message_dialog_add_responses (ADW_MESSAGE_DIALOG (dlg),
+                                          "yes", _("_Install Anyway"),
+                                          "no", _("_Go Back"),
+                                          NULL);
+
+        adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (dlg), "yes", ADW_RESPONSE_DESTRUCTIVE);
+        adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (dlg), "no", ADW_RESPONSE_SUGGESTED);
+
+        adw_message_dialog_set_default_response (ADW_MESSAGE_DIALOG (dlg), "no");
+        adw_message_dialog_set_close_response (ADW_MESSAGE_DIALOG (dlg), "no");
 
         UnsupportedDialogData *data = g_new0 (UnsupportedDialogData, 1);
         data->manager = g_object_ref (self->manager);
         data->uuid = g_strdup (uuid);
 
         g_signal_connect (dlg, "response", G_CALLBACK (extension_unsupported_dialog_response), data);
-        gtk_widget_show (dlg);
+        gtk_window_present (GTK_WINDOW (dlg));
 
         return;
     }
@@ -293,14 +310,15 @@ show_view (GtkWidget  *widget,
         gchar *uuid;
 
         g_variant_get (param, "s", &uuid);
-        adw_leaflet_set_visible_child (self->leaflet, GTK_WIDGET (self->detail_view));
+        adw_navigation_page_set_title (ADW_NAVIGATION_PAGE (self->detail_view), uuid);
+        adw_navigation_view_push (self->navigation_view, ADW_NAVIGATION_PAGE (self->detail_view));
 
         exm_detail_view_load_for_uuid (self->detail_view, uuid);
 
         return;
     }
 
-    adw_leaflet_set_visible_child (self->leaflet, self->main_view);
+    adw_navigation_view_pop_to_page (self->navigation_view, self->main_view);
 }
 
 static void
@@ -364,7 +382,7 @@ on_error (ExmManager *manager,
           char       *error_text,
           ExmWindow  *self)
 {
-    gtk_widget_activate_action (self, "win.show-error", "s", error_text);
+    gtk_widget_activate_action (GTK_WIDGET (self), "win.show-error", "s", error_text);
 }
 
 static void
@@ -391,7 +409,7 @@ exm_window_class_init (ExmWindowClass *klass)
     gtk_widget_class_bind_template_child (widget_class, ExmWindow, header_bar);
     gtk_widget_class_bind_template_child (widget_class, ExmWindow, installed_page);
     gtk_widget_class_bind_template_child (widget_class, ExmWindow, browse_page);
-    gtk_widget_class_bind_template_child (widget_class, ExmWindow, leaflet);
+    gtk_widget_class_bind_template_child (widget_class, ExmWindow, navigation_view);
     gtk_widget_class_bind_template_child (widget_class, ExmWindow, main_view);
     gtk_widget_class_bind_template_child (widget_class, ExmWindow, detail_view);
     gtk_widget_class_bind_template_child (widget_class, ExmWindow, title);
@@ -446,7 +464,7 @@ exm_window_init (ExmWindow *self)
     title = IS_DEVEL ? _("Extension Manager (Development)") : _("Extension Manager");
 
     gtk_window_set_title (GTK_WINDOW (self), title);
-    adw_view_switcher_title_set_title (self->title, title);
+    adw_navigation_page_set_title (self->main_view, title);
 
     g_object_set (self->installed_page, "manager", self->manager, NULL);
     g_object_set (self->browse_page, "manager", self->manager, NULL);
